California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 001A - SAFE, RELIABLE HIGH-SPEED PASSENGER TRAIN BOND ACT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1311754 | CALIFORNIA PUBLIC INTEREST RESEARCH GROUP SUPPORTERS FOR PROP 1A | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1305068 | CALIFORNIANS FOR HIGH SPEED TRAINS-YES ON PROPOSITION 1A-A COALITION OF TAXPAYER, BUSINESS, ENVIRONMENTAL AND LABOR GROUPS AND PEOPLE FROM ACROSS CALIFORNIA TIRED OF BEING STUCK IN TRAFFIC | SUPPORT